import { PostgrestSingleResponse, PostgrestMaybeSingleResponse, PostgrestResponse } from '@supabase/supabase-js';

declare const DEFAULT_SCHEMA_NAME = "public";

type PostgrestPaginationCacheData<Type> = Type[][];
type PostgrestCacheData<Type> = Pick<PostgrestSingleResponse<Type>, "data"> | Pick<PostgrestMaybeSingleResponse<Type>, "data"> | Pick<PostgrestResponse<Type>, "data" | "count"> | PostgrestPaginationCacheData<Type>;
declare const isPaginationCacheData: <Type>(data: PostgrestCacheData<Type>) => data is PostgrestPaginationCacheData<Type>;
type RevalidateTableOpt = {
    schema?: string;
    table: string;
};
type RevalidateRelationOpt<Type> = {
    schema?: string;
    relation: string;
    relationIdColumn: string;
    fKeyColumn: keyof Type;
};
type PostgrestMutatorOpts<Type> = {
    /**
     * Will set all keys of the tables to stale
     */
    revalidateTables?: RevalidateTableOpt[];
    /**
     * Will set all keys of the tables where relation.primaryKey === myObj.fKey
     */
    revalidateRelations?: RevalidateRelationOpt<Type>[];
};
type DecodedKey = {
    bodyKey: string | undefined;
    queryKey: string;
    count: string | null;
    schema: string | undefined;
    table: string;
    isHead: boolean | undefined;
    limit: number | undefined;
    offset: number | undefined;
};

export { DEFAULT_SCHEMA_NAME, DecodedKey, PostgrestCacheData, PostgrestMutatorOpts, RevalidateRelationOpt, RevalidateTableOpt, isPaginationCacheData };
